Add Arkham to probe IDs and include memory info

BUG=chrome-os-partner:42141
BRANCH=none
TEST=crossystem prints all the values. mosys platform name prints Arkham

Change-Id: I954678af4c47094a6293ce4b1fbccde978741419
Signed-off-by: Suresh Rajashekara <sureshraj@chromium.org>
Reviewed-on: https://chromium-review.googlesource.com/283040
Reviewed-by: David Hendricks <dhendrix@chromium.org>
(cherry picked from commit 76c28170df1c27cc7d84075cbb509615ff6d3405)
Reviewed-on: https://chromium-review.googlesource.com/289231
Reviewed-by: Patrick Sosinski <sosinski@google.com>
Commit-Queue: Patrick Sosinski <sosinski@google.com>
Tested-by: Patrick Sosinski <sosinski@google.com>
diff --git a/platform/google/storm/storm.c b/platform/google/storm/storm.c
index b67a350..250d936 100644
--- a/platform/google/storm/storm.c
+++ b/platform/google/storm/storm.c
@@ -46,11 +46,13 @@
 enum storm_boards {
 	STORM,
 	WHIRLWIND,
+	ARKHAM,
 };
 
 static const char *id_list[] = {
 	[STORM] = "google,storm",
 	[WHIRLWIND] = "google,whirlwind",
+	[ARKHAM] = "google,arkham",
 	NULL,
 };
 
@@ -75,6 +77,9 @@
 
 		if (index == WHIRLWIND)
 			intf->name = "Whirlwind";
+
+		if (index == ARKHAM)
+			intf->name = "Arkham";
 	}
diff --git a/platform/google/storm/memory.c b/platform/google/storm/memory.c
index 2a9cab4..38c80a2 100644
--- a/platform/google/storm/memory.c
+++ b/platform/google/storm/memory.c
@@ -89,7 +89,7 @@
  */
 static int dimm_count(struct platform_intf *intf)
 {
 	/* same for whirlwind */
 	return STORM_DIMM_COUNT;
 }
 
@@ -99,6 +99,8 @@
 		return SAMSUNG_DDR3_1600_1G;
 	else if (!strcmp(intf->name, "Whirlwind"))
 		return MICRON_DDR3L_1600_1G;
+	else if (!strcmp(intf->name, "Arkham"))
+		return MICRON_DDR3L_1600_1G;
 	return MEM_UNKNOWN;
 }
 
@@ -89,7 +89,7 @@
 static int dimm_count(struct platform_intf *intf)
 {
-	/* same for whirlwind */
+	/* same for whirlwind and Arkham */
 	return STORM_DIMM_COUNT;
 }